MockBitGoClient

Struct MockBitGoClient 

pub struct MockBitGoClient { /* private fields */ }

Implementations

Source

impl MockBitGoClient

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl MockBitGoClient

pub fn expect_get_transaction(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_transaction method

pub fn expect_transfer_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the transfer_list method

pub fn expect_get_fee(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_fee method

pub fn expect_change_fee(&mut self) -> &mut Expectation

Create an Expectation for mocking the change_fee method

Source

impl MockBitGoClient

pub fn expect_generate_wallet(&mut self) -> &mut Expectation

Create an Expectation for mocking the generate_wallet method

pub fn expect_generate_enterprise_wallet(&mut self) -> &mut Expectation

Create an Expectation for mocking the generate_enterprise_wallet method

pub fn expect_create_address(&mut self) -> &mut Expectation

Create an Expectation for mocking the create_address method

pub fn expect_get_wallet_list(&mut self) -> &mut Expectation

Create an Expectation for mocking the get_wallet_list method

Source

impl MockBitGoClient

pub fn expect_add_wallet_webhook(&mut self) -> &mut Expectation

Create an Expectation for mocking the add_wallet_webhook method

pub fn expect_add_block_webhook(&mut self) -> &mut Expectation

Create an Expectation for mocking the add_block_webhook method

pub fn expect_list_wallet_webhook(&mut self) -> &mut Expectation

Create an Expectation for mocking the list_wallet_webhook method

pub fn expect_list_block_webhook(&mut self) -> &mut Expectation

Create an Expectation for mocking the list_block_webhook method

pub fn expect_remove_wallet_webhook(&mut self) -> &mut Expectation

Create an Expectation for mocking the remove_wallet_webhook method

pub fn expect_remove_block_webhook(&mut self) -> &mut Expectation

Create an Expectation for mocking the remove_block_webhook method